@@ -1,21 +1,23 @@
 import argparse
 import typing
 import pathlib
+import textwrap
 
-import discord
-
-from .runner import run_bot, run_website, run_sharder
+from .runner import run_bot, run_website, run_sharder, run_shell, run_modify_commands
 
 
 def create_file(*path, content: str = None):
     joined_folder_path = pathlib.Path("./").joinpath(*path[:-1])
     joined_file_path = pathlib.Path("./").joinpath(*path)
-    joined_folder_path.mkdir(parents=True, exist_ok=True)
-    try:
-        with open(joined_file_path, "x") as a:
-            a.write(content)
-    except FileExistsError:
-        print(f"File {joined_file_path} was not created as one already exists.")
+    if content:
+        joined_folder_path.mkdir(parents=True, exist_ok=True)
+        try:
+            with open(joined_file_path, "x") as a:
+                a.write(content)
+        except FileExistsError:
+            print(f"File {joined_file_path} was not created as one already exists.")
+    else:
+        joined_file_path.mkdir(parents=True, exist_ok=True)
 
 
 # Parse arguments
@@ -44,6 +46,8 @@ def get_default_program_arguments() -> argparse.ArgumentParser:
     bot_subparser = runner_subparser.add_parser("run-bot")
     website_subparser = runner_subparser.add_parser("run-website")
     sharder_subparser = runner_subparser.add_parser("run-sharder")
+    shell_subparser = runner_subparser.add_parser("run-shell")
+    application_subparser = runner_subparser.add_parser("commands")
     create_config_subparser = runner_subparser.add_parser("create-config")
     check_config_subparser = runner_subparser.add_parser("check-config")
     runner_subparser.add_parser("version")
@@ -71,6 +75,16 @@ def get_default_program_arguments() -> argparse.ArgumentParser:
     sharder_subparser.add_argument("--concurrency", nargs="?", default=1, type=int, help="The max concurrency of the connecting bot.")
     sharder_subparser.add_argument("--loglevel", nargs="?", default="INFO", help="Global logging level - probably most useful is INFO and DEBUG.", choices=LOGLEVEL_CHOICES)
 
+    # Set up the shell arguments
+    shell_subparser.add_argument("bot_directory", nargs="?", default=".", help="The directory containing a config and a cogs folder for the bot to run.")
+    shell_subparser.add_argument("config_file", nargs="?", default="config/config.toml", help="The configuration for the bot.")
+
+    # Set up the shell arguments
+    application_subparser.add_argument("action", help="The action yuou want to take on your application commands.", choices=["add", "remove"])
+    application_subparser.add_argument("bot_directory", nargs="?", default=".", help="The directory containing a config and a cogs folder for the bot to run.")
+    application_subparser.add_argument("config_file", nargs="?", default="config/config.toml", help="The configuration for the bot.")
+    application_subparser.add_argument("--guild", nargs="?", default=None, type=int, help="The guild that you want to modify the application commands for.")
+
     # See what we want to make a config file for
     create_config_subparser.add_argument("config_type", nargs=1, help="The type of config file that we want to create.", choices=["bot", "website", "all"])
     check_config_subparser.add_argument("config_type", nargs=1, help="The type of config file that we want to create.", choices=["bot", "website"])
@@ -87,9 +101,11 @@ def check_config_value(
     Recursively checks a config item to see if it's valid against a base config item
     """
 
+    default_value = base_config_value if not isinstance(base_config_value, str) else textwrap.dedent(base_config_value).replace("\n", "\\n")
+
     # See if the item was omitted
     if isinstance(compare_config_value, type(None)):
-        print(f"No value {base_config_key} was provided in your config file - should be type {type(base_config_value).__name__}.")
+        print(f"No value {base_config_key} was provided in your config file - should be type {type(base_config_value).__name__} (default {default_value!r}).")
         if isinstance(base_config_value, dict):
             for i, o in base_config_value.items():
                 check_config_value(base_config_key + [i], o, None)
@@ -97,7 +113,7 @@ def check_config_value(
 
     # See if the item was a str when it should be something else
     if not isinstance(base_config_value, type(compare_config_value)):
-        print(f"Wrong value {base_config_key} type was provided in your config file - should be type {type(base_config_value).__name__}.")
+        print(f"Wrong value {base_config_key} type was provided in your config file - should be type {type(base_config_value).__name__} (default {default_value!r}).")
         if isinstance(base_config_value, dict):
             for i, o in base_config_value.items():
                 check_config_value(base_config_key + [i], o, None)
@@ -127,25 +143,24 @@ def main():
             create_file("config", "website.toml", content=config.web_config_file.lstrip())
             create_file("config", "website.example.toml", content=config.web_config_file.lstrip())
             create_file("config", "database.pgsql", content=config.database_file.lstrip())
-            # create_file("run_website.bat", content="py -m voxelbotutils run-website .\n")
             create_file("_run_website.sh", content="vbu run-website .\n")
-            create_file(".gitignore", content="__pycache__/\nconfig/config.toml\nconfig/website.toml\n")
+            create_file(".gitignore", content="__pycache__/\n.venv/\nconfig/config.toml\nconfig/website.toml\n")
             create_file("requirements.txt", content="voxelbotutils[web]\n")
             create_file("website", "frontend.py", content=config.website_frontend_content.lstrip())
             create_file("website", "backend.py", content=config.website_backend_content.lstrip())
             create_file("website", "static", ".gitkeep", content="\n")
             create_file("website", "templates", ".gitkeep", content="\n")
+            create_file(".venv")
             print("Created website config file.")
         if config_type in ["bot", "all"]:
             create_file("config", "config.toml", content=config.config_file.lstrip())
             create_file("config", "config.example.toml", content=config.config_file.lstrip())
             create_file("config", "database.pgsql", content=config.database_file.lstrip())
             create_file("cogs", "ping_command.py", content=config.cog_example.lstrip())
-            # create_file("run_bot.bat", content="py -m voxelbotutils run-bot .\n")
             create_file("_run_bot.sh", content="vbu run-bot .\n")
-            # create_file("run_bot.py", content=config.run_bot_python_file.lstrip())
             create_file(".gitignore", content="__pycache__/\nconfig/config.toml\nconfig/website.toml\n")
             create_file("requirements.txt", content="voxelbotutils\n")
+            create_file(".venv")
             print("Created bot config file.")
         exit(1)
 
@@ -154,11 +169,12 @@ def main():
         config_type = args.config_type[0]
         from . import config
         import toml
-        if config_type == "web":
+        if config_type == "website":
             base_config_file_text = config.web_config_file.lstrip()
         elif config_type == "bot":
             base_config_file_text = config.config_file.lstrip()
-        # todo: what happens if the option given isn't web or bot?
+        else:
+            exit(1)
         base_config_file = toml.loads(base_config_file_text)
         try:
             with open(args.config_file) as a:
@@ -168,6 +184,7 @@ def main():
             exit(0)
         for key, value in base_config_file.items():
             check_config_value([key], value, compare_config_file.get(key))
+        print("Completed config check.")
         exit(1)
 
     # If we just want the version
@@ -183,6 +200,10 @@ def main():
         run_website(args)
     elif args.subcommand == "run-sharder":
         run_sharder(args)
+    elif args.subcommand == "run-shell":
+        run_shell(args)
+    elif args.subcommand == "commands":
+        run_modify_commands(args)
 
 
 if __name__ == '__main__':
