@@ -1,43 +1,73 @@
-import asyncio
-
 import discord
-from discord.ext import commands
 
-from . import utils
+from . import utils as vbu
 from .. import __version__
 
 
-class BotStats(utils.Cog):
+class BotStats(vbu.Cog):
 
-    @utils.command(aliases=['git', 'code'], add_slash_command=False)
-    @utils.checks.is_config_set('command_data', 'github_link')
-    @commands.bot_has_permissions(send_messages=True)
-    async def github(self, ctx: utils.Context):
+    @vbu.command()
+    @vbu.checks.is_config_set('bot_info', 'enabled')
+    @vbu.bot_has_permissions(send_messages=True)
+    async def info(self, ctx: vbu.Context):
         """
-        Sends the GitHub Repository link.
+        Gives you information about the bot, including some important links, such as its invite.
         """
 
-        await ctx.send(f"<{self.bot.config['command_data']['github_link']}>", embeddify=False)
+        # Get the info embed
+        bot_info = self.bot.config.get("bot_info", {})
+        info_embed = vbu.Embed(
+            description=bot_info.get("content", "").format(bot=self.bot),
+        ).set_author_to_user(
+            self.bot.user,
+        )
 
-    @utils.command()
-    @commands.bot_has_permissions(send_messages=True)
-    @utils.checks.is_config_set('oauth', 'enabled')
-    async def invite(self, ctx: utils.Context):
+        # See if we have images
+        if bot_info.get("thumbnail"):
+            info_embed.set_thumbnail(bot_info["thumbnail"])
+        if bot_info.get("image"):
+            info_embed.set_image(bot_info["image"])
+
+        # Make up our buttons
+        links = bot_info.get("links", dict())
+        buttons = []
+        if (invite_link := self.get_invite_link()):
+            buttons.append(vbu.Button(label="Invite", url=invite_link, style=vbu.ButtonStyle.LINK))
+        for label, info in links.items():
+            buttons.append(vbu.Button(emoji=info.get("emoji") or None, label=label, url=info['url'], style=vbu.ButtonStyle.LINK))
+        components = vbu.MessageComponents.add_buttons_with_rows(*buttons)
+
+        # And send
+        return await ctx.send(embed=info_embed, components=components, wait=False)
+
+    def get_invite_link(self):
         """
-        Gives you the bot's invite link.
+        Get the invite link for the bot.
         """
 
-        oauth = self.bot.config['oauth'].copy()
+        if not self.bot.config.get("oauth", {}).get("enabled", True):
+            return None
+        oauth = self.bot.config.get("oauth", {}).copy()
         permissions = discord.Permissions.none()
         for i in oauth.pop('permissions', list()):
             setattr(permissions, i, True)
         oauth['permissions'] = permissions
-        await ctx.send(f"<{self.bot.get_invite_link(**oauth)}>", embeddify=False)
+        return self.bot.get_invite_link(**oauth)
 
-    @utils.command()
-    @commands.bot_has_permissions(send_messages=True)
-    @utils.checks.is_config_set('command_data', 'vote_command_enabled')
-    async def vote(self, ctx: utils.Context):
+    @vbu.command()
+    @vbu.bot_has_permissions(send_messages=True)
+    @vbu.checks.is_config_set('oauth', 'enabled')
+    async def invite(self, ctx: vbu.Context):
+        """
+        Gives you the bot's invite link.
+        """
+
+        await ctx.send(f"<{self.get_invite_link()}>", embeddify=False)
+
+    @vbu.command()
+    @vbu.bot_has_permissions(send_messages=True)
+    @vbu.checks.is_config_set('bot_listing_api_keys', 'topgg_token')
+    async def vote(self, ctx: vbu.Context):
         """
         Gives you a link to vote for the bot.
         """
@@ -52,22 +82,24 @@ class BotStats(utils.Cog):
             return await ctx.send("Despite being enabled, the vote command has no vote links to provide :/")
         return await ctx.send("\n".join(output_strings), embeddify=False)
 
-    @utils.command(aliases=['status', 'botinfo'], add_slash_command=False)
-    @commands.bot_has_permissions(send_messages=True, embed_links=True)
-    @utils.checks.is_config_set('command_data', 'stats_command_enabled')
-    async def stats(self, ctx: utils.Context):
+    async def get_stats_embed(self):
         """
-        Gives you the stats for the bot.
+        Get the stats embed - now as a function so I can use it in multiple places.
         """
 
         # Get creator info
-        creator_id = self.bot.config["owners"][0]
-        creator = self.bot.get_user(creator_id) or await self.bot.fetch_user(creator_id)
+        try:
+            creator_id = self.bot.config["owners"][0]
+            creator = self.bot.get_user(creator_id) or await self.bot.fetch_user(creator_id)
+        except IndexError:
+            creator_id = None
+            creator = None
 
         # Make embed
-        embed = utils.Embed(use_random_colour=True)
+        embed = vbu.Embed(use_random_colour=True)
         embed.set_footer(f"{self.bot.user} - VoxelBotUtils v{__version__}", icon_url=self.bot.user.avatar_url)
-        embed.add_field("Creator", f"{creator!s}\n{creator_id}")
+        if creator_id:
+            embed.add_field("Creator", f"{creator!s}\n{creator_id}")
         embed.add_field("Library", f"Discord.py {discord.__version__}")
         if self.bot.shard_count != len((self.bot.shard_ids or [0])):
             embed.add_field(
@@ -78,14 +110,6 @@ class BotStats(utils.Cog):
             embed.add_field("Guild Count", f"{len(self.bot.guilds):,}")
         embed.add_field("Shard Count", f"{self.bot.shard_count or 1:,}")
         embed.add_field("Average WS Latency", f"{(self.bot.latency * 1000):.2f}ms")
-        try:
-            all_tasks = asyncio.Task.all_tasks()
-        except AttributeError:
-            all_tasks = asyncio.all_tasks()
-        embed.add_field(
-            "Coroutines",
-            f"{len([i for i in all_tasks if not i.done()]):,} running, {len(all_tasks):,} total.",
-        )
 
         # Get topgg data
         if self.bot.config.get('bot_listing_api_keys', {}).get("topgg_token"):
@@ -132,10 +156,19 @@ class BotStats(utils.Cog):
                 except KeyError:
                     embed.add_field(**content)
 
-        # Send it out wew let's go
+        return embed
+
+    @vbu.command(aliases=['status', 'botinfo'], add_slash_command=False)
+    @vbu.bot_has_permissions(send_messages=True, embed_links=True)
+    async def stats(self, ctx: vbu.Context):
+        """
+        Gives you the stats for the bot.
+        """
+
+        embed = await self.get_stats_embed()
         await ctx.send(embed=embed)
 
 
-def setup(bot: utils.Bot):
+def setup(bot: vbu.Bot):
     x = BotStats(bot)
     bot.add_cog(x)
