@@ -1,12 +1,12 @@
-from . import utils
+from . import utils as vbu
 
 
-class CommandEvent(utils.Cog):
+class CommandEvent(vbu.Cog):
 
     CONTENT_LIMIT = 50
 
-    @utils.Cog.listener()
-    async def on_command(self, ctx: utils.Context):
+    @vbu.Cog.listener()
+    async def on_command(self, ctx: vbu.Context):
         """
         Pinged when a command is invoked.
         """
@@ -17,12 +17,17 @@ class CommandEvent(utils.Cog):
         content = ctx.message.content.replace('\n', '\\n')[:self.CONTENT_LIMIT]
         if len(ctx.message.content) > self.CONTENT_LIMIT:
             content += '...'
-        invoke_text = "Interaction invoked" if ctx.is_interaction else "Command invoked"
+        invoke_text = "Command invoked"
+        if ctx.is_interaction:
+            if getattr(ctx, "given_values", None) is not None:
+                invoke_text = "Context invoked"
+            else:
+                invoke_text = "Interaction invoked"
         if ctx.guild is None:
             return logger.info(f"{invoke_text} ({ctx.invoked_with}) ~ (G0/C{ctx.channel.id}/U{ctx.author.id}) :: {content}")
         logger.info(f"{invoke_text} ({ctx.invoked_with}) ~ (G{ctx.guild.id}/C{ctx.channel.id}/U{ctx.author.id}) :: {content}")
 
 
-def setup(bot: utils.Bot):
+def setup(bot: vbu.Bot):
     x = CommandEvent(bot)
     bot.add_cog(x)
