@@ -2,7 +2,7 @@ from datetime import datetime as dt
 
 import discord
 
-from . import utils
+from . import utils as vbu
 
 
 def try_id(item):
@@ -23,7 +23,7 @@ def try_username(bot):
         return bot.application_id
 
 
-class ConnectEvent(utils.Cog):
+class ConnectEvent(vbu.Cog):
 
     async def send_webhook(self, event_name: str, text: str, username: str, logger: str) -> bool:
         """
@@ -54,13 +54,12 @@ class ConnectEvent(utils.Cog):
         self.logger.info(logger)
         return True
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_shard_connect(self, shard_id: int):
         """
         Ping a given webhook when the shard ID is connected.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "shard_connect",
             f"Shard connect event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
@@ -68,13 +67,12 @@ class ConnectEvent(utils.Cog):
             f"Sent webhook for on_shard_connect event in shard `{shard_id}`",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_shard_ready(self, shard_id: int):
         """
         Ping a given webhook when the shard ID becomes ready.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "shard_ready",
             f"Shard ready event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
@@ -82,13 +80,12 @@ class ConnectEvent(utils.Cog):
             f"Sent webhook for on_shard_ready event in shard `{shard_id}`",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_ready(self):
         """
         Ping a given webhook when the bot becomes ready.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "bot_ready",
             f"Bot ready event just pinged for instance with shards `{self.bot.shard_ids}` - {dt.utcnow().strftime('%X.%f')}",
@@ -96,13 +93,12 @@ class ConnectEvent(utils.Cog):
             "Sent webhook for on_ready event",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_shard_disconnect(self, shard_id: int):
         """
         Ping a given webhook when the shard ID is disconnected.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "shard_disconnect",
             f"Shard disconnect event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
@@ -110,13 +106,12 @@ class ConnectEvent(utils.Cog):
             f"Sent webhook for on_shard_disconnect event in shard `{shard_id}`",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_disconnect(self):
         """
         Ping a given webhook when the bot is disconnected.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "bot_disconnect",
             f"Bot disconnect event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
@@ -124,13 +119,12 @@ class ConnectEvent(utils.Cog):
             "Sent webhook for on_disconnect event",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_shard_resumed(self, shard_id: int):
         """
         Ping a given webhook when the shard ID is resumed.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "shard_connect",
             f"Shard resumed event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
@@ -138,13 +132,12 @@ class ConnectEvent(utils.Cog):
             f"Sent webhook for on_shard_resumed event in shard `{shard_id}`",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_resumed(self):
         """
         Ping a given webhook when the bot is resumed.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "bot_connect",
             f"Bot resumed event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
@@ -152,13 +145,12 @@ class ConnectEvent(utils.Cog):
             "Sent webhook for on_resumed event",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_guild_join(self, guild: discord.Guild):
         """
         Ping a given webhook when the bot is added to a guild.
         """
 
-        application_id = self.bot.application_id
         await self.send_webhook(
             "guild_join",
             f"Added to new guild - ``{guild.name}``/``{guild.id}`` (`{guild.member_count}` members)",
@@ -166,19 +158,18 @@ class ConnectEvent(utils.Cog):
             "Sent webhook for on_guild_join event",
         )
 
-    @utils.Cog.listener()
+    @vbu.Cog.listener()
     async def on_guild_remove(self, guild: discord.Guild):
         """
         Ping a given webhook when the bot is removed from a guild.
         """
 
-        application_id = self.bot.application_id
         if guild.me:
             try:
                 member_count = guild.member_count
-                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{member_count}` members; `{utils.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
+                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{member_count}` members; `{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
             except Exception:
-                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{utils.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
+                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
             await self.send_webhook(
                 "guild_remove",
                 text,
@@ -199,6 +190,6 @@ class ConnectEvent(utils.Cog):
             )
 
 
-def setup(bot: utils.Bot):
+def setup(bot: vbu.Bot):
     x = ConnectEvent(bot)
     bot.add_cog(x)
