@@ -1,7 +1,7 @@
-# flake8: noqa
 from .is_config_set import is_config_set
 from .meta_command import meta_command
 from .bot_is_ready import bot_is_ready
 from .is_bot_support import is_bot_support
 from .is_voter import is_voter
-from .is_upgrade_chat_subscriber import is_upgrade_chat_subscriber
+from .is_upgrade_chat_subscriber import is_upgrade_chat_subscriber, is_upgrade_chat_purchaser
+from .slash_commands import is_slash_command, is_not_slash_command, bot_in_guild
