@@ -6,7 +6,9 @@ import argparse
 from discord.ext import commands
 from discord.ext.commands.core import wrap_callback
 
+from .custom_context import PrintContext
 from .custom_cog import Cog
+from .interactions.application_commands import ApplicationCommandType
 
 
 class DiscordArgparser(argparse.ArgumentParser):
@@ -80,6 +82,10 @@ class Command(commands.Command):
                 async def ban(self, ctx, user: discord.Member, *, namespace: argparse.Namespace):
                     ban_time: int = namespace.days  # Conversion is handled automatically
                     ...
+
+        context_command_type (voxelbotutils.ApplicationCommandType): The type of context command that your
+            given command should be added as.
+        context_command_name (str): The name of the context command that should be added.
     """
 
     def __init__(self, *args, **kwargs):
@@ -91,6 +97,8 @@ class Command(commands.Command):
         self.add_slash_command: bool = kwargs.get('add_slash_command', True)
         self.argument_descriptions: typing.List[str] = kwargs.get('argument_descriptions', list())
         self.argparse: list = kwargs.get('argparse', list())
+        self.context_command_type: ApplicationCommandType = kwargs.get("context_command_type", None)
+        self.context_command_name: str = kwargs.get("context_command_name", None)
 
         # Fix cooldown to be our custom type
         cooldown = self._buckets._cooldown
@@ -158,8 +166,9 @@ class Command(commands.Command):
 
         ctx.command = self
 
-        if not await self.can_run(ctx):
-            raise commands.CheckFailure('The check functions for command {0.qualified_name} failed.'.format(self))
+        if not isinstance(ctx, PrintContext):
+            if not await self.can_run(ctx):
+                raise commands.CheckFailure('The check functions for command {0.qualified_name} failed.'.format(self))
 
         if self._max_concurrency is not None:
             await self._max_concurrency.acquire(ctx)
